@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2003 Sun Microsystems, Inc.
+ * Copyright (C) 2004 Red Hat Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -29,11 +30,14 @@
 
 G_BEGIN_DECLS
 
-char *netstatus_sysdeps_read_iface_statistics (const char *iface,
-					       long       *in_packets,
-					       long       *out_packets,
-					       long       *in_bytes,
-					       long       *out_bytes);
+char *netstatus_sysdeps_read_iface_statistics       (const char *iface,
+						     long       *in_packets,
+						     long       *out_packets,
+						     long       *in_bytes,
+						     long       *out_bytes);
+char *netstatus_sysdeps_read_iface_wireless_details (const char *iface,
+						     gboolean   *is_wireless,
+						     int        *signal_strength);
 
 G_END_DECLS
 
